<?xml version='1.0'?>
<!-- vim:set sts=2 shiftwidth=2 syntax=sgml: -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xt="http://www.jclark.com/xt"
                extension-element-prefixes="xt"
                version='1.0'>

<xsl:include href="http://docbook.sourceforge.net/release/xsl/current/common/common.xsl"/>

<xsl:include href="synop.xsl"/>
<xsl:include href="lists.xsl"/>

<xsl:output method="text"
            encoding="ISO-8859-1"
            indent="no"/>

<xsl:template name="f">
  <xsl:param name="content" select="''"/>
  <xsl:param name="attribute" select="''"/>
  <xsl:text>\f</xsl:text>
  <xsl:value-of select="$attribute"/>
  <xsl:value-of select="$content"/>
  <xsl:text>\fR</xsl:text>
</xsl:template>

<xsl:template name="fB">
  <xsl:param name="content" select="''"/>
  <xsl:call-template name="f">
    <xsl:with-param name="content" select="$content"/>
    <xsl:with-param name="attribute" select="'B'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="fI">
  <xsl:param name="content" select="''"/>
  <xsl:call-template name="f">
    <xsl:with-param name="content" select="$content"/>
    <xsl:with-param name="attribute" select="'I'"/>
  </xsl:call-template>
</xsl:template>

<xsl:template name="write-page">
  <xsl:param name="filename" select="''"/>
  <xsl:param name="contents" select="''"/>
  <xt:document href="{$filename}" method="text" indent="no"
               encoding="ISO-8859-1">
    <xsl:copy-of select="$contents"/>
  </xt:document>
</xsl:template>

<xsl:template match="refsect2">
  <xsl:text>
.Sh "</xsl:text>
  <xsl:value-of select="substring-before(title[1],' ')"/>
  <xsl:text>"
</xsl:text>
  <xsl:apply-templates/>
</xsl:template>
<xsl:template match="refsect2/programlisting"></xsl:template>

<xsl:template match="refsect2/informaltable/tgroup/tbody/row">
  <xsl:text>.Ip "\(bu \s-1</xsl:text>
  <xsl:value-of select="entry[1]/parameter[1]"/>
  <xsl:text>\s0 \- </xsl:text>
  <xsl:value-of select="normalize-space(entry[2])"/>
  <xsl:text>"
</xsl:text>
</xsl:template>

<xsl:template match="refsect1">
  <xsl:text>
.SH "</xsl:text>
  <xsl:value-of select="translate(title[1],'abcdefghijklmnopqrstuvwxyz', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ')"/>
  <xsl:text>"
</xsl:text>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="refsynopsisdiv">
  <xsl:text>
.SH "SYNOPSIS"
</xsl:text>
  <xsl:apply-templates/>
</xsl:template>


<xsl:template match="para">
  <xsl:variable name="foo">
    <xsl:apply-templates/>
  </xsl:variable>
  <xsl:text>
.PP
</xsl:text>
  <xsl:value-of select="normalize-space($foo)"/>
  <xsl:text>
</xsl:text>
</xsl:template>

<xsl:template match="simpara">
  <xsl:variable name="foo">
    <xsl:apply-templates/>
  </xsl:variable>
  <xsl:text>

</xsl:text>
  <xsl:value-of select="normalize-space($foo)"/>
  <xsl:text>
</xsl:text>
</xsl:template>


<xsl:template match="refentry">
  <xsl:variable name="section" select="refmeta/manvolnum"/>
  <xsl:variable name="name" select="refmeta/refentrytitle"/>

  <xsl:call-template name="write-page">
    <xsl:with-param name="filename">
      <xsl:value-of select="$name"/>.<xsl:value-of select="$section"/>
    </xsl:with-param>
    <xsl:with-param name="contents">
      <xsl:text>."Generated by db2man.xsl. Don't modify this, modify the source.
.de Sh \" Subsection
.br
.if t .Sp
.ne 5
.PP
\fB\\$1\fR
.PP
..
.de Sp \" Vertical space (when we can't use .PP)
.if t .sp .5v
.if n .sp
..
.de Ip \" List item
.br
.ie \\n(.$>=3 .ne \\$3
.el .ne 3
.IP "\\$1" \\$2
..
.TH "</xsl:text>
      <xsl:value-of select="refmeta/refentrytitle"/>
      <xsl:text>" </xsl:text>
      <xsl:value-of select="refmeta/manvolnum[1]"/>
      <xsl:text> "" "" "</xsl:text>
      <xsl:value-of select="refentryinfo/title"/>
      <xsl:text>"
</xsl:text>
      <xsl:apply-templates/>
      <xsl:if test="refentryinfo/author">
        <xsl:text>&#10;.SH AUTHOR&#10;</xsl:text>
        <xsl:apply-templates select="refentryinfo/author"/>
      </xsl:if>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template match="refmeta"></xsl:template>
<xsl:template match="title"></xsl:template>


<xsl:template match="author">
  <xsl:call-template name="person.name"/>
</xsl:template>

<xsl:template match="copyright">
  <xsl:text>Copyright </xsl:text>
  <xsl:apply-templates/>
  <xsl:text>
.Sp
</xsl:text>
</xsl:template>

<xsl:template match="email">
  <xsl:text>  &lt;</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>&gt;</xsl:text>
</xsl:template>

<xsl:template match="refnamediv">
  <xsl:text>.SH NAME
</xsl:text>
  <xsl:for-each select="refname">
    <xsl:if test="position()>1">
      <xsl:text>, </xsl:text>
    </xsl:if>
    <xsl:value-of select="."/>
  </xsl:for-each>
  <xsl:text> \- </xsl:text>
  <xsl:value-of select="refpurpose"/>
</xsl:template>

<xsl:template match="refentry/refentryinfo"></xsl:template>

<xsl:template match="option">
  <xsl:text>\fB</xsl:text><xsl:apply-templates/><xsl:text>\fR</xsl:text>
</xsl:template>

<xsl:template match="replaceable">
  <xsl:text>\fI</xsl:text><xsl:apply-templates/><xsl:text>\fR</xsl:text>
</xsl:template>

<xsl:template match="filename">
  <xsl:text>
.FN </xsl:text><xsl:apply-templates/>
</xsl:template>

<xsl:template match="userinput">
  <xsl:text>\fB</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>\fR</xsl:text>
</xsl:template>

<xsl:template match="informalexample|screen">
  <xsl:text>&#10;.IP&#10;.B </xsl:text><xsl:apply-templates/>
</xsl:template>

<xsl:template match="envar">
  <xsl:text>\fB</xsl:text><xsl:apply-templates/><xsl:text>\fR</xsl:text>
</xsl:template>

<xsl:template match="filename">
  <xsl:text>\fI</xsl:text><xsl:apply-templates/><xsl:text>\fR</xsl:text>
</xsl:template>

<xsl:template match="ulink">
  <xsl:apply-templates/>
  <xsl:text>: \fI</xsl:text>
  <xsl:value-of select="@url"/>
  <xsl:text>\fR</xsl:text>
</xsl:template>

<xsl:template match="errorcode|constant">
  <xsl:call-template name="fB">
    <xsl:with-param name="content">
      <xsl:apply-templates/>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template match="quote">
  <xsl:text>``</xsl:text>
  <xsl:apply-templates/>
  <xsl:text>''</xsl:text>
</xsl:template>

<xsl:template match="/">
  <xsl:apply-templates select="//refentry"/>
</xsl:template>

</xsl:stylesheet>
