<?xml version='1.0'?> <!-- -*- xml -*- -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xt="http://www.jclark.com/xt"
                extension-element-prefixes="xt"
                version='1.0'>

<xsl:output method="text" indent="no" encoding="ISO-8859-1"/>
<xsl:strip-space elements="*"/>

<!-- This file is part of the xmlto package and may be distributed
     under the terms of the GNU General Public License.            -->

<xsl:template name="write-page">
  <xsl:param name="filename" select="''"/>
  <xsl:param name="contents" select="''"/>
  <xt:document href="{$filename}" method="text" indent="no"
               encoding="ISO-8859-1">
    <xsl:copy-of select="$contents"/>
  </xt:document>
</xsl:template>

<xsl:template match="refentry">
  <xsl:variable name="section" select="refmeta/manvolnum"/>
  <xsl:variable name="name" select="refmeta/refentrytitle"/>

  <xsl:call-template name="write-page">
    <xsl:with-param name="filename">
      <xsl:value-of select="$name"/>.<xsl:value-of select="$section"/>
    </xsl:with-param>
    <xsl:with-param name="contents">
      <xsl:text>.\" This manpage has been generated&#10;</xsl:text>
      <xsl:text>.\" using troff.xsl.&#10;</xsl:text>
      <xsl:apply-templates/>
    </xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template match="refmeta">
  <xsl:text>.TH "</xsl:text>
  <xsl:value-of select="refentrytitle"/>
  <xsl:text>" "</xsl:text>
  <xsl:value-of select="manvolnum"/>
  <xsl:text>"&#10;</xsl:text>
</xsl:template>

<xsl:template match="refnamediv">
  <xsl:text>.SH NAME&#10;</xsl:text>
  <xsl:for-each select="refname">
    <xsl:if test="position()>1">
      <xsl:text>, </xsl:text>
    </xsl:if>
    <xsl:value-of select="."/>
  </xsl:for-each>
  <xsl:text> \- </xsl:text>
  <xsl:value-of select="refpurpose"/>
  <xsl:text>&#10;</xsl:text>
</xsl:template>

<xsl:template match="refsynopsisdiv">
  <xsl:text>.SH SYNOPSIS&#10;&#10;</xsl:text>
  <xsl:apply-templates mode="refsynopsisdiv"/>
</xsl:template>

<xsl:template match="synopsis" mode="refsynopsisdiv">
  <xsl:text>.nf&#10;</xsl:text>
  <xsl:value-of select="."/>
  <xsl:text>&#10;.fi&#10;</xsl:text>
</xsl:template>

<xsl:template match="funcsynopsis" mode="refsynopsisdiv">
  <xsl:apply-templates mode="refsynopsisdiv"/>
</xsl:template>

<xsl:template match="funcprototype" mode="refsynopsisdiv">
  <xsl:text>.sp&#10;</xsl:text>
  <xsl:apply-templates mode="refsynopsisdiv"/>
</xsl:template>

<xsl:template match="funcdef" mode="refsynopsisdiv">
  <xsl:apply-templates mode="refsynopsisdiv"/>
</xsl:template>

<xsl:template match="paramdef" mode="refsynopsisdiv">
  <xsl:text> (</xsl:text>
  <xsl:apply-templates mode="refsynopsisdiv"/>
  <xsl:text>)</xsl:text>
</xsl:template>

<xsl:template match="function|parameter" mode="refsynopsisdiv">
  <xsl:text>\fB</xsl:text>
  <xsl:value-of select="."/>
  <xsl:text>\fR</xsl:text>
</xsl:template>

<xsl:template match="/">
  <xsl:apply-templates select="//refentry"/>
</xsl:template>

<xsl:template match="*"/>

</xsl:stylesheet>
